import * as apigateway from 'aws-cdk-lib/aws-apigateway';
import { Construct } from 'constructs';
import { Allocate } from '../allocate';
import { Deallocate } from '../deallocate';
/**
 * Options for `Endpoint`.
 */
export interface EndpointOptions {
    /**
     * List of accounts that are allowed to access the endpoint.
     *
     * @default - only the service account is allowed.
     */
    readonly allowedAccounts?: string[];
}
/**
 * Properties `Endpoint`.
 */
export interface EndpointProps extends EndpointOptions {
    /**
     * Allocate function.
     */
    readonly allocate: Allocate;
    /**
     * Deallocate function.
     */
    readonly deallocate: Deallocate;
}
export declare class Endpoint extends Construct {
    /**
     * Api Gateway rest api.
     */
    readonly api: apigateway.RestApi;
    /**
     * Allocations sub resource.
     */
    readonly allocationsResource: apigateway.Resource;
    /**
     * Allocation sub resource.
     */
    readonly allocationResource: apigateway.Resource;
    constructor(scope: Construct, id: string, props: EndpointProps);
}
